package sample.acegi;

import org.acegisecurity.Authentication;
import org.acegisecurity.AuthenticationException;
import org.acegisecurity.AuthenticationManager;
import org.acegisecurity.GrantedAuthority;
import org.acegisecurity.providers.UsernamePasswordAuthenticationToken;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.context.support.ClassPathXmlApplicationContext;

public class AuthenticationSample {
    private static final Log LOG
                = LogFactory.getLog(AuthenticationSample.class);

    public static void main(String[] args) {
        BeanFactory factory = new ClassPathXmlApplicationContext(
                                        "/sample/acegi/applicationContext.xml");
        AuthenticationManager authenticationManager =
            (AuthenticationManager) factory.getBean("authenticationManager");

        Authentication authTaro =
            new UsernamePasswordAuthenticationToken("taro", "taropassword");

        Authentication authResultTaro = authenticationManager.authenticate(authTaro);

        logAuthentication(authResultTaro);

        Authentication passwordInvalid =
            new UsernamePasswordAuthenticationToken("taro", "invalidpassword");

        try {
            authenticationManager.authenticate(passwordInvalid);
        } catch (AuthenticationException e) {
            LOG.info("Password Invalid -> throws AuthenticationException");
        }

        Authentication authNotFound =
            new UsernamePasswordAuthenticationToken("notfound", "notfoundpassword");

        try {
            authenticationManager.authenticate(authNotFound);
        } catch (AuthenticationException e) {
            LOG.info("User Not Found -> throws AuthenticationException");
        }

        Authentication authDisabled =
            new UsernamePasswordAuthenticationToken("jiro", "jiropassword");

        try {
            authenticationManager.authenticate(authDisabled);
        } catch (AuthenticationException e) {
            LOG.info("Disabled User -> throws AuthenticationException");
        }
    }
    
    private static void logAuthentication(Authentication authentication) {
        LOG.info("LOGIN NAME : " + authentication.getName());
        LOG.info("AUTHORITIS : ");
        for (GrantedAuthority authority : authentication.getAuthorities()) {
            LOG.info("  auhority : " + authority);
        }
    }

}
