package sample.acegi;

import java.util.List;

import org.acegisecurity.AccessDeniedException;
import org.acegisecurity.Authentication;
import org.acegisecurity.AuthenticationManager;
import org.acegisecurity.context.SecurityContext;
import org.acegisecurity.context.SecurityContextHolder;
import org.acegisecurity.providers.UsernamePasswordAuthenticationToken;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import sample.acegi.domain.Person;
import sample.acegi.domain.PersonService;

public class AuthorizationSample {
    private static final Log LOG
                = LogFactory.getLog(AuthorizationSample.class);

    public static void main(String[] args) {
        BeanFactory factory = new ClassPathXmlApplicationContext(
                                        "/sample/acegi/applicationContext.xml");

        PersonService personService = (PersonService) factory.getBean("personService");

        AuthenticationManager authenticationManager =
            (AuthenticationManager) factory.getBean("authenticationManager");

        Authentication authentication = authenticationManager.authenticate(
                new UsernamePasswordAuthenticationToken("saburo", "saburopassword"));

        SecurityContext securityCtx = SecurityContextHolder.getContext();
        securityCtx.setAuthentication(authentication);

        List<Person> personList = personService.findAll();

        Person person = personService.findByPk(1);

        try {
            personService.create(new Person(10, "\q", "ޗǌ", 58));
        } catch (AccessDeniedException e) {
            LOG.info("access denied -> throws AccessDeniedException");
        }
    }
}
